@@ -43,13 +43,32 @@ free_hash(gpointer key, gpointer value, gpointer user_data)
  	g_print("FREE - key:%p, value:%p\n", key, value);
  //	xmlFreeDoc(key);
 }
+
+gchar *
+strextr(gchar *text, gchar *substr)
+{
+ 	g_return_val_if_fail( text != NULL, NULL);
+	char *tmp = g_strdup(text);
+	GString *str = g_string_new(NULL);
+	g_string_append(str, tmp);
+	str = g_string_erase(str, strlen(tmp) - strlen(strstr(tmp, substr)), strlen(substr));
+	gchar *string = str->str;	
+	g_string_free(str, 0);
+	g_free(tmp);
+	return string;
+}
  
 //prefixes uri with http:// if it's misssing
 //resulting text should be freed when no longer needed
 gchar *
 sanitize_url(gchar *text)
 {
- 	if (!strstr (text, "http://") && !strstr (text, "https://"))
+	if (strstr(text, "feed//"))
+		text = strextr(text, "feed//");
+	if (strstr(text, "feed://"))
+		text = strextr(text, "feed://");
+ 	if (!strstr (text, "http://") 
+	&& !strstr (text, "https://"))
  		return g_strconcat("http://", text, NULL);
  	else
  		return g_strdup(text);
@@ -279,6 +298,23 @@ decode_token (const char **in)
         }
 }
 
+gchar *extract_main_folder(gchar *folder)
+{
+	gchar *main_folder = lookup_main_folder();
+        gchar *base = g_strdup_printf("%s/", main_folder);
+        gchar **nnew;
+	gchar *tmp;
+	if (nnew = g_strsplit(folder, base, 0))
+	{
+		g_free(base);
+		tmp = g_strdup(nnew[1]);
+		g_strfreev(nnew);
+		return tmp;
+	}
+	else
+		return NULL;
+}
+
 /* hrm, is there a library for this shit? */
 static struct {
         char *name;
