@@ -126,10 +126,8 @@ recv_msg (SoupMessage *msg, gpointer user_data)
 #else
 	response = g_string_new_len(msg->response_body->data, msg->response_body->length);
 #endif
-#ifdef RSS_DEBUG
-	g_print("got it!\n");
-	g_print("res:[%s]\n", response->str);
-#endif
+	d(g_print("got it!\n"));
+	d(g_print("res:[%s]\n", response->str));
 }
 
 static gboolean
@@ -153,9 +151,7 @@ construct_abort(gpointer key, gpointer value, gpointer user_data)
 static void
 unblock_free (gpointer user_data, GObject *ex_msg)
 {
-#ifdef RSS_DEBUG
-	g_print("weak ref - trying to free object\n");
-#endif
+	d(g_print("weak ref - trying to free object\n"));
 	g_hash_table_remove(rf->session, user_data);
 	g_hash_table_destroy(rf->abort_session);
 	rf->abort_session = g_hash_table_new(g_direct_hash, g_direct_equal);
@@ -174,8 +170,9 @@ unblock_free (gpointer user_data, GObject *ex_msg)
 void
 proxify_session(SoupSession *session)
 {
-	gboolean use_proxy =
-       	gconf_client_get_bool(rss_gconf, GCONF_KEY_USE_PROXY, NULL);
+#if (EVOLUTION_VERSION < 22300)		// include devel too
+    gboolean use_proxy =
+   	gconf_client_get_bool(rss_gconf, GCONF_KEY_USE_PROXY, NULL);
     gint port_proxy =
         gconf_client_get_int(rss_gconf, GCONF_KEY_PORT_PROXY, NULL);
     gchar *host_proxy =
@@ -186,6 +183,24 @@ proxify_session(SoupSession *session)
         gconf_client_get_string(rss_gconf, GCONF_KEY_USER_PROXY, NULL);
     gchar *pass_proxy =
         gconf_client_get_string(rss_gconf, GCONF_KEY_PASS_PROXY, NULL);
+#else
+    gboolean use_proxy =
+   	gconf_client_get_bool(rss_gconf, GCONF_E_USE_PROXY_KEY, NULL);
+    guint proxy_type =
+   	gconf_client_get_int(rss_gconf, GCONF_E_PROXY_TYPE_KEY, NULL);
+    if (proxy_type != 2)	//emulate the same behaviour
+	use_proxy = 0;
+    gint port_proxy =
+        gconf_client_get_int(rss_gconf, GCONF_E_HTTP_PORT_KEY, NULL);
+    gchar *host_proxy =
+        gconf_client_get_string(rss_gconf, GCONF_E_HTTP_HOST_KEY, NULL);
+    gboolean auth_proxy =
+        gconf_client_get_bool(rss_gconf, GCONF_E_USE_AUTH_KEY, NULL);
+    gchar *user_proxy =
+        gconf_client_get_string(rss_gconf, GCONF_E_AUTH_USER_KEY, NULL);
+    gchar *pass_proxy =
+        gconf_client_get_string(rss_gconf, GCONF_E_AUTH_PWD_KEY, NULL);
+#endif
 
     if (use_proxy && host_proxy && port_proxy > 0)
     {
@@ -221,8 +236,7 @@ read_up(gpointer data)
 	g_free(tmp);
 	guint res = 0;
 
-	gchar *feed_dir = g_strdup_printf("%s/mail/rss",
-            mail_component_peek_base_directory (mail_component_peek ()));
+	gchar *feed_dir = rss_component_peek_base_directory(mail_component_peek());
 	if (!g_file_test(feed_dir, G_FILE_TEST_EXISTS))
             g_mkdir_with_parents (feed_dir, 0755);
 
@@ -252,8 +266,7 @@ save_up(gpointer data)
 	g_free(tmp);
 	guint res = 0;
 
-	gchar *feed_dir = g_strdup_printf("%s/mail/rss",
-            mail_component_peek_base_directory (mail_component_peek ()));
+	gchar *feed_dir = rss_component_peek_base_directory(mail_component_peek());
 	if (!g_file_test(feed_dir, G_FILE_TEST_EXISTS))
             g_mkdir_with_parents (feed_dir, 0755);
 
@@ -282,8 +295,7 @@ del_up(gpointer data)
 	gchar *tmp = gen_md5(data);
 	gchar *buf = g_strconcat(tmp, ".rec", NULL);
 	g_free(tmp);
-	gchar *feed_dir = g_strdup_printf("%s/mail/rss",
-            mail_component_peek_base_directory (mail_component_peek ()));
+	gchar *feed_dir = rss_component_peek_base_directory(mail_component_peek());
 	if (!g_file_test(feed_dir, G_FILE_TEST_EXISTS))
             g_mkdir_with_parents (feed_dir, 0755);
 
@@ -389,6 +401,7 @@ gboolean
 net_get_unblocking(const char *url, NetStatusCallback cb, 
 				gpointer data, gpointer cb2,
 				gpointer cbdata2,
+				guint track,
 				GError **err)
 {
 	SoupMessage *msg;
@@ -425,9 +438,14 @@ net_get_unblocking(const char *url, NetStatusCallback cb,
 				soup_status_get_phrase(2));			//invalid url
 		return -1;
 	}
-	g_hash_table_insert(rf->session, soup_sess, msg);
-	g_hash_table_insert(rf->abort_session, soup_sess, msg);
-	g_hash_table_insert(rf->key_session, data, soup_sess);
+	if (track)
+	{
+		//we want to be able to abort this session by calling
+		//abort_all_soup
+		g_hash_table_insert(rf->session, soup_sess, msg);
+		g_hash_table_insert(rf->abort_session, soup_sess, msg);
+		g_hash_table_insert(rf->key_session, data, soup_sess);
+	}
 
 	gchar *agstr = g_strdup_printf("Evolution/%s; Evolution-RSS/%s",
 			EVOLUTION_VERSION_STRING, VERSION);
