@@ -38,10 +38,31 @@ typedef struct _RDF {
         guint 		type_id; 	//num type
 	gchar		*version;	//feed version
         gchar		*feedid;  	//md5 string id of feed
+	GtkWidget	*progress;
+	guint		total;		//total articles
+	guint		ttl;		//feed specified refresh interval
         /* Soup stuff */
         SoupMessage *message;
 } RDF;
 
+//we keep these values of a feed to be deleted in order
+//to easily restore in case delete does not success or
+//it is canceled
+typedef struct _hrfeed {
+	gchar *hrname;
+	gchar *hrname_r;
+	gchar *hr;
+	guint hre;
+	gchar *hrt;
+	guint hrh;
+	guint hrdel_feed;
+	guint hrdel_days;
+	guint hrdel_messages;
+	guint hrdel_unread;
+	guint hrupdate;
+	guint hrttl;
+} hrfeed;
+
 typedef struct _rssfeed {
         GHashTable      *hrname;            	//bind feed name to key
         GHashTable      *hrname_r;            	//and mirrored structure for faster lookups
@@ -58,6 +79,8 @@ typedef struct _rssfeed {
         GHashTable      *hrdel_days;   		//option to delete messages older then days
         GHashTable      *hrdel_messages; 	//option to keep last messages
         GHashTable      *hrdel_unread; 		//option to delete unread messages too
+        GHashTable      *hrttl;   		//feeds name hash
+        GHashTable      *hrupdate;   		//feeds update method
         GtkWidget       *feed_dialog;
         GtkWidget       *progress_dialog;
         GtkWidget       *progress_bar;
@@ -113,14 +136,10 @@ typedef struct _rssfeed {
 #define GCONF_KEY_START_CHECK "/apps/evolution/evolution-rss/startup_check"
 #define GCONF_KEY_REP_CHECK "/apps/evolution/evolution-rss/rep_check"
 #define GCONF_KEY_REP_CHECK_TIMEOUT "/apps/evolution/evolution-rss/rep_check_timeout"
-#define GCONF_KEY_USE_PROXY "/apps/evolution/evolution-rss/use_proxy"
-#define GCONF_KEY_HOST_PROXY "/apps/evolution/evolution-rss/host_proxy"
-#define GCONF_KEY_PORT_PROXY "/apps/evolution/evolution-rss/port_proxy"
-#define GCONF_KEY_AUTH_PROXY "/apps/evolution/evolution-rss/auth_proxy"
-#define GCONF_KEY_USER_PROXY "/apps/evolution/evolution-rss/user_proxy"
-#define GCONF_KEY_PASS_PROXY "/apps/evolution/evolution-rss/pass_proxy"
 #define GCONF_KEY_REMOVE_FOLDER "/apps/evolution/evolution-rss/remove_folder"
 #define GCONF_KEY_HTML_RENDER "/apps/evolution/evolution-rss/html_render"
+#define GCONF_KEY_HTML_JS "/apps/evolution/evolution-rss/html_js"
+#define GCONF_KEY_HTML_JAVA "/apps/evolution/evolution-rss/html_java"
 
 enum {
 	RSS_FEED,
@@ -130,6 +149,7 @@ enum {
 
 typedef struct ADD_FEED {
 	GtkWidget	*dialog;
+	GtkWidget	*progress;
         gchar           *feed_url;
 	gchar		*feed_name;
         gboolean        fetch_html;	//show webpage instead of summary
@@ -141,6 +161,8 @@ typedef struct ADD_FEED {
 	guint		del_days;	// delete messages over del_days old
 	guint		del_messages;	// delete all messages but the last del_messages
 	gboolean	del_unread;	// delete unread messages too
+	guint		ttl;	// recommended update time
+	guint		update;	// feed update method global; ttl; disabled
 } add_feed;
 
 typedef struct USERPASS {
@@ -260,7 +282,13 @@ void taskbar_push_message(gchar *message);
 void taskbar_pop_message(void);
 void write_feeds_folder_line(gpointer key, gpointer value, FILE *file);
 void populate_reversed(gpointer key, gpointer value, GHashTable *hash);
-
+gchar *rss_component_peek_base_directory(MailComponent *component);
+static void custom_feed_timeout(void);
+static char *layer_find (xmlNodePtr node, char *match, char *fail);
+static char *layer_find_innerelement (xmlNodePtr node, char *match, char *el, char *fail);
+static gchar *layer_find_innerhtml (xmlNodePtr node, char *match, char *submatch, char *fail);
+xmlNodePtr layer_find_pos (xmlNodePtr node, char *match, char *submatch);
+static char *layer_find_tag (xmlNodePtr node, char *match, char *fail);
 
 
 typedef struct FEED_FOLDERS {
